package org.example.controller;

import lombok.RequiredArgsConstructor;
import org.example.dto.PassingDTO;
import org.example.dto.UpdateUserStatusDTO;
import org.example.dto.UserDTO;
import org.example.service.PassingService;
import org.example.service.UserService;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.Authentication;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("api")
@RequiredArgsConstructor
public class UserController {

    private final UserService userService;
    private final PassingService passingService;

    @GetMapping("/{username}/auth")
    public ResponseEntity<String> getUserByUsername(@PathVariable String username) {
        UserDTO userDTO = userService.getUserByUsername(username);
        return ResponseEntity.ok("данный логин существует - можно пользоваться приложением");
    }

    @GetMapping("/{username}/info")
    public ResponseEntity<UserDTO> getUserInfoByUsername(@PathVariable String username) {
        return ResponseEntity.ok(userService.getUserInfoByUsername(username));
    }

    @PatchMapping("/{username}/open")
    public ResponseEntity<String> patchUserByUsername(@PathVariable String username) {
        UserDTO userDTO = userService.patchUserByUsername(username);
        return ResponseEntity.ok("дверь открылась");
    }

    @GetMapping("/{username}/passing")
    public List<PassingDTO> getPassingByUsername(@PathVariable String username) {
        return passingService.getPassingByUsername(username);
    }

    @GetMapping("/{username}/passing/paginated")
    public ResponseEntity<Page<PassingDTO>> getAllPassingPaginated(
            @RequestParam(defaultValue = "0") int page,
            @RequestParam(defaultValue = "1") int size) {
        Pageable pageable = PageRequest.of(page, size);
        return ResponseEntity.ok(passingService.getAllPassingPaginated(pageable));
    }

    @PostMapping("/{username}/passing/new")
    public ResponseEntity<PassingDTO> createPassing(@RequestBody PassingDTO dto) {
        return ResponseEntity.status(HttpStatus.CREATED).body(passingService.createPassing(dto));
    }

    @GetMapping("/passing")
    public List<PassingDTO> getAllPassing(String authority) {
        return passingService.getAllPassing(authority);
    }

    @GetMapping("/login")
    public ResponseEntity<UserDTO> login(Authentication authentication){
        return  ResponseEntity.ok(userService.getUserByUsername(authentication.getName()));
    }

    @PatchMapping("/{username}")
    public ResponseEntity<UserDTO> updateUserStatus(@PathVariable String username, @RequestBody UpdateUserStatusDTO dto) {
        return ResponseEntity.ok(userService.patchUserStatusByUsername(username, dto));

    }
}
