package org.example.service.impl;

import lombok.RequiredArgsConstructor;
import org.example.dto.PassingDTO;
import org.example.entity.Passing;
import org.example.entity.User;
import org.example.exception.AuthorityNotFoundException;
import org.example.repository.PassingRepository;
import org.example.repository.UserRepository;
import org.example.service.PassingService;
import org.example.util.PassingMapper;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

@Service
@RequiredArgsConstructor
public class PassingServiceImpl implements PassingService {
    private final PassingRepository passingRepository;
    private final UserRepository userRepository;

    @Override
    public List<PassingDTO> getAllPassing(String authority) {
        Optional<User> userOptional = userRepository.findByAuthority("ROLE_ADMIN");
        if (userOptional.isEmpty()) {
            throw new AuthorityNotFoundException("Ошибка доступа");
        }

        return passingRepository.findAll().stream().map(PassingMapper::convertToDto).collect(Collectors.toList());
    }

    @Override
    public List<PassingDTO> getPassingByUsername(String Username) {
        return passingRepository.findByUsername(Username).stream().map(PassingMapper::convertToDto).collect(Collectors.toList());

    }

    @Override
    public Page<PassingDTO> getAllPassingPaginated(Pageable pageable) {
        return passingRepository.findAll(pageable).map(PassingMapper::convertToDto);
    }

    @Override
    public PassingDTO createPassing(PassingDTO dto) {
        Passing passing = new Passing();
        passing.setId(dto.getId());
        passing.setUsername(dto.getUsername());
        passing.setType(dto.getType());
        passing.setTime(dto.getTime());
        passing.setCode(dto.getCode());

        return PassingMapper.convertToDto(passingRepository.save(passing));
    }
}
